Video Patch Similarity Search (VPSS)
=========================================
A Python Implementation for a GPU accelerated implementation of Video Patch Similarity Searching.


Install
-------

The package is available through Python pip,

```
$ python -m pip install vpss --user
```

Or the package can be downloaded through github,

```
$ git clone https://github.com/gauenk/vpss/
$ cd vpss
$ python -m pip install -r requirements.txt --user
$ python -m pip install -e ./lib --user
```

LICENSE
-------

Licensed under the GNU Affero General Public License v3.0, see `LICENSE`.
